@@ -1,11 +1,14 @@
 ##----------------------------------------------------------------------------
 ## CSS Object Oriented - ~/lib/CSS/Object/Builder.pm
-## Version v0.1.1
+## Version v0.2.0
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <@sitael.local>
+## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/06/21
-## Modified 2020/06/24
+## Modified 2024/09/05
+## All rights reserved
 ## 
+## This program is free software; you can redistribute  it  and/or  modify  it
+## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 package CSS::Object::Builder;
 BEGIN
@@ -13,8 +16,7 @@ BEGIN
     use strict;
     use warnings;
     use parent qw( Module::Generic );
-    use Devel::Confess;
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.2.0';
 };
 
 sub init
@@ -123,7 +125,6 @@ BEGIN
     use strict;
     use warnings;
     use parent qw( CSS::Object::Rule );
-    use Devel::Confess;
 };
 
 sub init
@@ -167,7 +168,7 @@ AUTOLOAD
 };
 
 1;
-
+# NOTE: POD
 __END__
 
 =encoding utf-8
@@ -201,7 +202,7 @@ CSS::Object::Builder - CSS Object Oriented Builder
 
 =head1 VERSION
 
-    v0.1.1
+    v0.2.0
 
 =head1 DESCRIPTION
 
