@@ -1,11 +1,14 @@
 ##----------------------------------------------------------------------------
 ## CSS Object Oriented - ~/lib/CSS/Object/Parser/Enhanced.pm
-## Version v0.1.0
+## Version v0.2.0
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
+## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/08/09
-## Modified 2020/08/09
+## Modified 2024/09/05
+## All rights reserved
 ## 
+## This program is free software; you can redistribute  it  and/or  modify  it
+## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 package CSS::Object::Parser::Enhanced;
 BEGIN
@@ -17,8 +20,7 @@ BEGIN
     use CSS::Object::Rule;
     use CSS::Object::Selector;
     use CSS::Object::Property;
-    use Devel::Confess;
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.2.0';
 };
 
 sub parse_string
@@ -216,7 +218,7 @@ sub _trim
 }
 
 1;
-
+# NOTE: POD
 __END__
 
 =encoding utf-8
@@ -237,7 +239,7 @@ CSS::Object::Parser::Enhanced - CSS Object Oriented Enhanced Parser
 
 =head1 VERSION
 
-    v0.1.0
+    v0.2.0
 
 =head1 DESCRIPTION
 
